/**
   The eval() method takes a BTree that is an expression tree
   and evaluates it to a integer value.

   The expression tree can contain the following five binary operators,
      +, -, *, /, ^
*/

public class Evaluate
{
   /**
      This eval() method is essentially a
      post-order traversal of the binary tree.
   */
   public static int eval(BTree tree)
   {
      int result = 0;

      if ( 0 == tree.degree() )  // a number (stops the recursion)
      {
         result = Integer.parseInt( tree.getElement() );
      }
      else
      {
         // recursively traverse the left sub tree
         int resultL = eval(tree.getLeftTree());

         // recursively traverse the right sub tree
         int resultR = eval(tree.getRightTree());

         // "process" the current node
         String op = tree.getElement();
         if ( op.equals("+") )
         {
            result = resultL + resultR;
         }
         else if ( op.equals("-") )
         {
           result = resultL - resultR;
         }
         else if ( op.equals("*") )
         {
           result = resultL * resultR;
         }
         else if ( op.equals("/") )
         {
           result = resultL / resultR;
         }
         else if ( op.equals("^") )
         {
           result = (int)Math.pow(resultL, resultR);
         }
         else
         {
            System.out.println("Illegal operator: " + op );
         }
      }
      return result;
   }//eval()

}//Evaluate